==========================================
Python bindings to the OpenStack Panko API
==========================================

.. image:: https://img.shields.io/pypi/v/pankoclient.svg
    :target: https://pypi.python.org/pypi/pankoclient/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/pankoclient.svg
    :target: https://pypi.python.org/pypi/pankoclient/
    :alt: Downloads

This is a client library for Panko built on the Panko API. It provides a
Python API (the ``pankoclient`` module) and a OSC (the openstackclient CLI)
command-line tool (``openstack event``).

* Free software: Apache license
* `PyPi`_ - package installation
* `Online Documentation`_
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Bugs`_ - issue tracking
* `Source`_

.. _PyPi: https://pypi.python.org/pypi/pankoclient
.. _Online Documentation: http://docs.openstack.org/developer/python-pankoclient
.. _Launchpad project: https://launchpad.net/python-pankoclient
.. _Blueprints: https://blueprints.launchpad.net/python-pankoclient
.. _Bugs: https://bugs.launchpad.net/python-pankoclient
.. _Source: https://git.openstack.org/cgit/openstack/python-pankoclient
